@@ -12,13 +12,17 @@ class BucketRouting:
         if self.arguments.bucket_commands is None:
             subprocess.call(['e2e_cli', 'bucket', '-h'])
 
-        elif self.arguments.bucket_commands == 'add':
+        elif self.arguments.bucket_commands == 'create':
             bucket_operations = bucketCrud(alias=self.arguments.alias )
             if(bucket_operations.possible):
                         try:
-                            bucket_operations.add_bucket()
+                            bucket_operations.create_bucket()
                         except KeyboardInterrupt:
                             Py_version_manager.py_print(" ")
+                        except Exception as e:
+                            e=str(e)
+                            if(e=="'data'" or e=="'code'"):
+                                Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
 
         elif self.arguments.bucket_commands == 'delete':
             bucket_operations = bucketCrud(alias=self.arguments.alias)
@@ -27,6 +31,10 @@ class BucketRouting:
                             bucket_operations.delete_bucket()
                         except KeyboardInterrupt:
                             Py_version_manager.py_print(" ")
+                        except Exception as e:
+                            e=str(e)
+                            if(e=="'data'" or e=="'code'"):
+                                Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
         
         elif self.arguments.bucket_commands == 'list':
             bucket_operations = bucketCrud(alias=self.arguments.alias)
@@ -35,5 +43,9 @@ class BucketRouting:
                             bucket_operations.list_bucket()
                         except KeyboardInterrupt:
                             Py_version_manager.py_print(" ")
+                        except Exception as e:
+                            e=str(e)
+                            if(e=="'data'" or e=="'code'"):
+                                Py_version_manager.py_print("Oops!! Your access credentials seems to have expired")
 
 
