@@ -4,7 +4,7 @@ import platform
 
 from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.core.alias_service import check_user_cred
-
+from e2e_cli.config.config_service import is_valid
 
 class AuthConfig:
     def __init__(self, **kwargs):
@@ -47,17 +47,24 @@ class AuthConfig:
     def add_json_to_file(self):
         api_access_credentials_object = {"api_key": self.kwargs["api_key"],
                                          "api_auth_token": self.kwargs["api_auth_token"]}
-        with open(self.file, 'r+') as file_reference:
-            read_string = file_reference.read()
-            if read_string == "":
-                file_reference.write(json.dumps({self.kwargs["alias"]:
-                                                     api_access_credentials_object}))
-            else:
-                api_access_credentials = json.loads(read_string)
-                api_access_credentials.update({self.kwargs["alias"]:
-                                                   api_access_credentials_object})
-                file_reference.seek(0)
-                file_reference.write(json.dumps(api_access_credentials))
+        if(is_valid(api_access_credentials_object["api_key"], api_access_credentials_object["api_auth_token"])):
+            with open(self.file, 'r+') as file_reference:
+                read_string = file_reference.read()
+                if read_string == "":
+                    file_reference.write(json.dumps({self.kwargs["alias"]:
+                                                        api_access_credentials_object}))
+                else:
+                    api_access_credentials = json.loads(read_string)
+                    api_access_credentials.update({self.kwargs["alias"]:
+                                                    api_access_credentials_object})
+                    file_reference.seek(0)
+                    file_reference.write(json.dumps(api_access_credentials))
+            Py_version_manager.py_print()
+            Py_version_manager.py_print("Alias/user_name/Token name successfully added")
+        else:
+            Py_version_manager.py_print()
+            Py_version_manager.py_print("Invalid credentials given please enter correct Api key and Authorisation")
+            return
 
     def add_to_config(self):
         file_exist_check_variable = self.check_if_file_exist()
@@ -87,8 +94,11 @@ class AuthConfig:
                 file_contents_object = json.loads(file_reference.read())
                 delete_output = file_contents_object.pop(self.kwargs["alias"], 'No key found')
                 if delete_output == "No key found":
+                    Py_version_manager.py_print()
                     Py_version_manager.py_print("No such alias found. Please re-check and enter again")
                 else:
                     file_reference.seek(0)
                     file_reference.write(json.dumps(file_contents_object))
                     file_reference.truncate()
+                    Py_version_manager.py_print()
+                    Py_version_manager.py_print("Alias/name Successfully deteted")
