@@ -7,6 +7,7 @@ from prettytable import PrettyTable
 from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.core.alias_service import AliasServices
 from e2e_cli.core.request_service import Request
+from e2e_cli.core.helper_service import Checks
 
 
 class DBaaSServices:
@@ -51,7 +52,11 @@ class DBaaSServices:
         for software_instance in software_engines:
             table.add_row([software_instance["id"], software_instance["name"], software_instance["version"]])
         Py_version_manager.py_print(table)
-        software_id = int(Py_version_manager.py_input(": "))
+        software_id = Py_version_manager.py_input(": ")
+        while(not Checks.is_int(software_id) or not 0<int(software_id)<=len(software_engines)):
+            Py_version_manager.py_print("Please select one of above only")
+            software_id = Py_version_manager.py_input(": ")
+        software_id=int(software_id)
         return software_engines[software_id-1]["id"]
     
     def select_a_template(self, software_id, api_key, api_auth_token):
@@ -67,6 +72,10 @@ class DBaaSServices:
             templates_id+=1
         Py_version_manager.py_print(table)
         template_id_choice = int(Py_version_manager.py_input(": "))
+        while(not Checks.is_int(template_id_choice) or not 0<int(template_id_choice)<=len(template_engines)):
+            Py_version_manager.py_print("Please select one of above only")
+            template_id_choice = Py_version_manager.py_input(": ")
+        template_id_choice=int(template_id_choice)
         return template_engines[template_id_choice-1]["template_id"]
     
 
@@ -74,7 +83,11 @@ class DBaaSServices:
         Py_version_manager.py_print("Fill in the details required")
         Py_version_manager.py_print("(Note: All the fields having a important ahead of them can't be skipped)")
         name_assigned_to_database = Py_version_manager.py_input("Name of your database(important): ")
+        while(name_assigned_to_database=="" or " " in name_assigned_to_database):
+            name_assigned_to_database = Py_version_manager.py_input("Re-enter, name can't have spaces :")
         username_assigned_to_database = Py_version_manager.py_input("Assign UserName to your database(important): ")
+        while(username_assigned_to_database=="" or " " in username_assigned_to_database):
+            username_assigned_to_database = Py_version_manager.py_input("Re-enter, username can't have spaces :")
         password_assigned_to_database = Py_version_manager.py_input("Assign Password to your database(important): ")
         while self.password_validate(password_assigned_to_database):
             Py_version_manager.py_print("  You need to correct your password")
@@ -118,6 +131,9 @@ class DBaaSServices:
 
     def delete_dbaas(self):
         database_id = Py_version_manager.py_input("Enter the id of the database: ")
+        while(not Checks.is_int(database_id)):
+            database_id = Py_version_manager.py_input("Enter a valid id : ") 
+        Py_version_manager.py_print("Load Balancing Property: ")
         Py_version_manager.py_print("Deleting this dbaas instance can cause data loss!")
         choice = Py_version_manager.py_input("Do you still want to continue?(Y/N)")
         if choice.upper() == "Y":
@@ -135,9 +151,10 @@ class DBaaSServices:
                 response = Request(req="DELETE", url=url, Auth_Token=Auth_Token, payload=payload).response.json()
 
                 if(not response["code"]==200):
-                        Py_version_manager.py_print("No Client found for the given api key")
-                else:        
-                   return {"dbaas_api_response": response,
-                        "message": api_key_credentials_object["message"]}
+                        Py_version_manager.py_print(response['errors'])
+                        return {"message": "Failure"}
+                else:      
+                    return {"dbaas_api_response": response,
+                            "message": api_key_credentials_object["message"]}
         else:
-            return {"message": "Failure"}
+            return {"message": "Aborted"}
